package com.inspect.metadata.montdata.service;

import com.inspect.metadata.montdata.domain.BasedataMontPatDevOnline;

import java.util.List;

public interface IBasedataMontPatDevOnlineService {
    BasedataMontPatDevOnline selectBasedataMontPatDevOnlineByPatDevOnlineId(Long onlineId);

    List<BasedataMontPatDevOnline> selectBasedataMontPatDevOnlineList(BasedataMontPatDevOnline online);

    int insertBasedataMontPatDevOnline(BasedataMontPatDevOnline online);

    int updateBasedataMontPatDevOnline(BasedataMontPatDevOnline online);

    int deleteBasedataMontPatDevOnlineByPatDevOnlineIds(Long[] onlineIds);

    int deleteBasedataMontPatDevOnlineByPatDevOnlineId(Long onlineId);
}
